@@ -19,10 +19,7 @@ except ImportError:
 import getpass
 DEFAULT_USER = getpass.getuser()
 
-try:
-    from cymysql.charsetx import charset_by_name, charset_by_id
-except ImportError:
-    from cymysql.charset import charset_by_name, charset_by_id
+from cymysql.charset import charset_by_name, charset_by_id
 from cymysql.cursors import Cursor
 from cymysql.constants.CLIENT import *
 from cymysql.constants.COMMAND import *
@@ -30,10 +27,7 @@ from cymysql.converters import decoders, encoders, escape_item
 from cymysql.err import raise_mysql_exception, Warning, Error, \
      InterfaceError, DataError, DatabaseError, OperationalError, \
      IntegrityError, InternalError, NotSupportedError, ProgrammingError
-try:
-    from cymysql.packetx import MysqlPacket, MySQLResult
-except ImportError:
-    from cymysql.packet import MysqlPacket, MySQLResult
+from cymysql.packet import MysqlPacket, MySQLResult
 
 PYTHON3 = sys.version_info[0] > 2
 
