@@ -49,10 +49,11 @@ def get_decode_values(values, charset, fields, use_unicode, decoders=default_dec
     r = [None] * len(values)
     for i, value in enumerate(values):
         if value is not None:
-            if decoders[fields[i].type_code] != default_decoders[fields[i].type_code]:
-                r[i] = decoders[fields[i].type_code](value)
+            type_code = fields[i].type_code
+            if decoders[type_code] != default_decoders[type_code]:
+                r[i] = decoders[type_code](value)
             else:
-                r[i] = decoders[fields[i].type_code](value, charset, fields[i], use_unicode)
+                r[i] = decoders[type_code](value, charset, fields[i], use_unicode)
     return r
 
 
@@ -65,10 +66,7 @@ class MysqlPacket(object):
         self.connection = connection
         self.__position = 0
         self.__recv_packet()
-        if PYTHON3:
-            is_error = self.__data[0] == 0xff
-        else:
-            is_error = self.__data[0] == b'\xff'
+        is_error = self.__data[0] == (0xff if PYTHON3 else b'\xff')
         if is_error:
             self.__position += 1  # field_count == error (we already know that)
             errno = unpack_uint16(self._read(2))
@@ -83,7 +81,7 @@ class MysqlPacket(object):
             size -= len(recv_data)
             r += recv_data
         return r
-  
+
     def __recv_packet(self):
         """Parse the packet header and read entire packet payload into buffer."""
         packet_header = self.__recv_from_socket(4)
@@ -102,7 +100,7 @@ class MysqlPacket(object):
         self.__data_length = bytes_to_read
   
     def get_all_data(self): return self.__data
-  
+
     def read(self, size):
         return self._read(size)
 
@@ -146,9 +144,6 @@ class MysqlPacket(object):
         else:
             return -1
   
-    def read_length_coded_string(self):
-        return self._read_length_coded_string()
-
     def _read_length_coded_string(self):
         """Read a 'Length Coded String' from the data buffer.
 
@@ -162,7 +157,7 @@ class MysqlPacket(object):
         return self._read(length)
 
     def read_decode_data(self, fields):
-        values = [self.read_length_coded_string() for f in fields]
+        values = [self._read_length_coded_string() for f in fields]
         return tuple(
             get_decode_values(values,
                 self.connection.charset,
@@ -172,25 +167,14 @@ class MysqlPacket(object):
         )
  
     def is_ok_packet(self):
-        if PYTHON3:
-            return self.__data[0] == 0
-        else:
-            return self.__data[0] == b'\x00'
+        return self.__data[0] == (0 if PYTHON3 else b'\x00')
 
     def is_eof_packet(self):
-        if PYTHON3:
-            return self.__data[0] == 0xfe
-        else:
-            return self.__data[0] == b'\xfe'
+        return self.__data[0] == (0xfe if PYTHON3 else b'\xfe')
 
     def is_eof_and_status(self):
-        if PYTHON3:
-            if self.__data[0] != 0xfe:
-                return False, 0, 0
-        else:
-            if self.__data[0] != b'\xfe':
-                return False, 0, 0
-
+        if self.__data[0] != (0xfe if PYTHON3 else b'\xfe'):
+            return False, 0, 0
         return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))
 
     def read_ok_packet(self):
@@ -240,21 +224,15 @@ class FieldDescriptorPacket(MysqlPacket):
 
     def description(self):
         """Provides a 7-item tuple compatible with the Python PEP249 DB Spec."""
-        desc = []
-        desc.append(self.name)
-        desc.append(self.type_code)
-        desc.append(None) # TODO: display_length; should this be self.length?
-        desc.append(self.get_column_length()) # 'internal_size'
-        desc.append(self.get_column_length()) # 'precision'  # TODO: why!?!?
-        desc.append(self.scale)
-  
-        # 'null_ok' -- can this be True/False rather than 1/0?
-        #              if so just do:  desc.append(bool(self.flags % 2 == 0))
-        if self.flags % 2 == 0:
-            desc.append(1)
-        else:
-            desc.append(0)
-        return tuple(desc)
+        return (
+            self.name,
+            self.type_code,
+            None,
+            self.get_column_length(),
+            self.get_column_length(),
+            self.scale,
+            1 if self.flags % 2 == 0 else 0,
+        )
 
     def get_column_length(self):
         if self.type_code == FIELD_TYPE_VAR_STRING:
